@@ -1,11 +1,20 @@
+"""
+Copyright 2021 Adobe
+All Rights Reserved.
+
+NOTICE: Adobe permits you to use, modify, and distribute this file in accordance
+with the terms of the Adobe license agreement accompanying it.
+"""
 
 import logging
 
 
-_LOGGER: logging.Logger = None
+# Global vars
+_LOGGER: logging.Logger
 
 
 def init_logger(debug: bool) -> None:
+    # pylint: disable=global-statement
     global _LOGGER
 
     log_level = logging.INFO
